@@ -140,7 +140,7 @@ var MapView = GObject.registerClass({
     _init(params) {
         super._init();
 
-        let mapType = params.mapType || MapType.STREET;
+        let mapType = params.mapType || this._getStoredMapType();
         delete params.mapType;
 
         this._mainWindow = params.mainWindow;
@@ -152,6 +152,9 @@ var MapView = GObject.registerClass({
 
         this.setMapType(mapType);
 
+        if (Application.normalStartup)
+            this._goToStoredLocation();
+
         this.shapeLayerStore = new Gio.ListStore(GObject.TYPE_OBJECT);
 
         Application.geoclue.connect('location-changed',
@@ -180,19 +183,12 @@ var MapView = GObject.registerClass({
     _initView() {
         let view = this.get_view();
 
-        // Start all the way zoomed out and centered on (0, 0)
-        // This way you can see the whole map on startup
-        view.zoom_level = MapMinZoom;
-        view.center_on(0, 0);
-
         view.min_zoom_level = MapMinZoom;
         view.goto_animation_mode = Clutter.AnimationMode.EASE_IN_OUT_CUBIC;
         view.reactive = true;
         view.kinetic_mode = true;
         view.horizontal_wrap = true;
 
-        if (Application.normalStartup)
-            view.connect('notify::realized', this._goToStoredLocation.bind(this));
         view.connect('notify::latitude', this._onViewMoved.bind(this));
         // switching map type will set view min-zoom-level from map source
         view.connect('notify::min-zoom-level', () => {
@@ -300,6 +296,23 @@ var MapView = GObject.registerClass({
         query.connect('notify', () => this.routingOpen = query.isValid());
     }
 
+    _getStoredMapType() {
+        let mapType = Application.settings.get('map-type');
+
+        // make sure it's a valid map type
+        for (let type in MapType) {
+            if (mapType === MapType[type]) {
+                return mapType;
+            }
+        }
+
+        return MapType.STREET;
+    }
+
+    getMapType() {
+        return this._mapType;
+    }
+
     setMapType(mapType) {
         if (this._mapType && this._mapType === mapType)
             return;
@@ -318,6 +331,8 @@ var MapView = GObject.registerClass({
                 this._attribution = new MapSource.AttributionLogo(this.view);
                 this.view.add_child(this._attribution);
             }
+
+            Application.settings.set('map-type', mapType);
         } else {
             let renderer = new Champlain.ImageRenderer();
             let source = new Maps.FileTileSource({
@@ -429,6 +444,18 @@ var MapView = GObject.registerClass({
         this._userLocation.goTo(animate);
     }
 
+    gotoAntipode() {
+        let lat = -this.view.latitude;
+        let lon = this.view.longitude > 0 ?
+                  this.view.longitude - 180 : this.view.longitude + 180;
+        let place =
+            new Place.Place({ location: new Location.Location({ latitude: lat,
+                                                                longitude: lon }),
+                              initialZoom: this.view.zoom_level });
+
+        new MapWalker.MapWalker(place, this).goTo(true);
+    }
+
     userLocationVisible() {
         let box = this.view.get_bounding_box();
 
@@ -460,21 +487,28 @@ var MapView = GObject.registerClass({
     }
 
     _storeLocation() {
-        let box = this.view.get_bounding_box();
-        let lastViewedLocation = [box.top, box.bottom, box.left, box.right];
-        Application.settings.set('last-viewed-location', lastViewedLocation);
+        Application.settings.set('zoom-level', this.view.zoom_level);
+        let location = [this.view.latitude, this.view.longitude];
+        Application.settings.set('last-viewed-location', location);
     }
 
     _goToStoredLocation() {
-        if (!this.view.realized)
-            return;
+        let location = Application.settings.get('last-viewed-location');
 
-        let box = Application.settings.get('last-viewed-location');
-        let bounding_box = new Champlain.BoundingBox({ top: box[0],
-                                                       bottom: box[1],
-                                                       left: box[2],
-                                                       right: box[3] });
-        this.gotoBBox(bounding_box, true);
+        if (location.length === 2) {
+            this.view.zoom_level = Application.settings.get('zoom-level');
+            this.view.center_on(location[0], location[1]);
+        } else {
+            /* bounding box. for backwards compatibility, not used anymore */
+            let bbox = new Champlain.BoundingBox({ top: location[0],
+                                                   bottom: location[1],
+                                                   left: location[2],
+                                                   right: location[3] });
+            this.view.connect("notify::realized", () => {
+                if (this.view.realized)
+                    this.gotoBBox(bbox, true);
+            });
+        }
     }
 
     gotoBBox(bbox, linear) {
